@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents data deduplication region.',
                                   class => 'DeduplicationRegion',
                                   required => [], # TODO
 }                                 );
@@ -128,14 +128,14 @@ __PACKAGE__->method_documentation({
      'ranges' => {
      	datatype => 'ARRAY[Range]',
      	base_name => 'Ranges',
-     	description => '',
+     	description => 'Represents data range.',
      	format => '',
      	read_only => '',
      		},
      'worksheet_name_list' => {
      	datatype => 'ARRAY[string]',
      	base_name => 'WorksheetNameList',
-     	description => '',
+     	description => 'Represents worksheet name list.',
      	format => '',
      	read_only => '',
      		},    
