@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents options of saving image file.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'ImageSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -128,84 +128,84 @@ __PACKAGE__->method_documentation({
      'chart_image_type' => {
      	datatype => 'string',
      	base_name => 'ChartImageType',
-     	description => 'Indicate the chart imagetype when converting.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'embeded_image_name_in_svg' => {
      	datatype => 'string',
      	base_name => 'EmbededImageNameInSvg',
-     	description => 'Indicate the filename of embeded image in svg. This should be full path with directory like "c:\\xpsEmbeded"',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'horizontal_resolution' => {
      	datatype => 'int',
      	base_name => 'HorizontalResolution',
-     	description => 'Gets or sets the horizontal resolution for generated images, in dots per inch.                 Applies generating image method except Emf format images.               The default value is 96.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'image_format' => {
      	datatype => 'string',
      	base_name => 'ImageFormat',
-     	description => 'Gets or sets the format of the generated images.  Don`t apply the method that returns a Bitmap object.             The default value is ImageFormat.Bmp.  Don`t apply the method that returns a Bitmap object.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'is_cell_auto_fit' => {
      	datatype => 'boolean',
      	base_name => 'IsCellAutoFit',
-     	description => 'Indicates whether the width and height of the cells is automatically fitted by cell value. The default value is false.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'one_page_per_sheet' => {
      	datatype => 'boolean',
      	base_name => 'OnePagePerSheet',
-     	description => 'If OnePagePerSheet is true , all content of one sheet will output to only                one page in result. The paper size of pagesetup will be invalid, and the                other settings of pagesetup will still take effect.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'only_area' => {
      	datatype => 'boolean',
      	base_name => 'OnlyArea',
-     	description => 'If this property is true , onle Area will be output, and no scale will take effect.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'printing_page' => {
      	datatype => 'string',
      	base_name => 'PrintingPage',
-     	description => 'Indicates which pages will not be printed.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'print_with_status_dialog' => {
      	datatype => 'boolean',
      	base_name => 'PrintWithStatusDialog',
-     	description => 'If PrintWithStatusDialog = true , there will be a dialog that shows current print status.  else no such dialog will show.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'quality' => {
      	datatype => 'int',
      	base_name => 'Quality',
-     	description => 'Gets or sets a value determining the quality of the generated images to apply only when saving pages to the Jpeg format.            Has effect only when saving to JPEG.  The value must be between 0 and 100. The default value is 100.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'tiff_compression' => {
      	datatype => 'string',
      	base_name => 'TiffCompression',
-     	description => 'Gets or sets the type of compression to apply only when saving pages to the Tiff format.            Has effect only when saving to TIFF.  The default value is Lzw.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'vertical_resolution' => {
      	datatype => 'int',
      	base_name => 'VerticalResolution',
-     	description => 'Gets or sets the vertical resolution for generated images, in dots per inch.            Applies generating image method except Emf format image.            The default value is 96.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
