@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents options of saving ooxml file.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'OoxmlSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -128,35 +128,35 @@ __PACKAGE__->method_documentation({
      'export_cell_name' => {
      	datatype => 'boolean',
      	base_name => 'ExportCellName',
-     	description => 'Indicates if export cell name to Excel2007 .xlsx (.xlsm, .xltx, .xltm) file.               If the output file may be accessed by SQL Server DTS, this value must be               true.  Setting the value to false will highly increase the performance and               reduce the file size when creating large file.  Default value is false.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'update_zoom' => {
      	datatype => 'boolean',
      	base_name => 'UpdateZoom',
-     	description => 'Indicates whether update scaling factor before saving the file if the PageSetup.FitToPagesWide and PageSetup.FitToPagesTall properties control how the worksheet is scaled.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'enable_zip64' => {
      	datatype => 'boolean',
      	base_name => 'EnableZip64',
-     	description => 'Always use ZIP64 extensions when writing zip archives, even when unnecessary.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'embed_ooxml_as_ole_object' => {
      	datatype => 'boolean',
      	base_name => 'EmbedOoxmlAsOleObject',
-     	description => 'Indicates whether embedding Ooxml files of OleObject as ole object.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'compression_type' => {
      	datatype => 'string',
      	base_name => 'CompressionType',
-     	description => 'Gets and sets the compression type for ooxml file.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
