@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -86,7 +87,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/metadata/delete';
+    my $_resource_path = 'v3.0/cells/metadata/delete';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -116,14 +117,10 @@ sub run_http_request {
         $query_params->{'checkExcelRestriction'} = $client->to_query_value($self->check_excel_restriction);      
     } 
     my $_body_data;
- 
 
-    if (defined $self->file) {   
-        my $map_file = $self->file;
-        while ( my ($filename,$value) = each( %$map_file ) ) {
-                $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
-        }
-    } 
+
+    $form_params->{basename($self->file)} = [$self->file ,basename($self->file),'application/octet-stream'];
+ 
 
     # authentication setting, if any
     my $auth_settings = [qw()];
