@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -88,7 +89,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/pivottables/{pivotTableIndex}/PivotField';
+    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/pivottables/{pivotTableIndex}/PivotField';
 
     my $_method = 'DELETE';
     my $query_params = {};
@@ -131,11 +132,14 @@ sub run_http_request {
     } 
     my $_body_data;
 
+
     # body params
     if (defined $self->pivot_table_field_request) {
-        #$_body_data = $self->pivot_table_field_request;
          $_body_data = JSON->new->convert_blessed->encode( $self->pivot_table_field_request);
     }
+
+ 
+
     # authentication setting, if any
     my $auth_settings = [qw()];
 
